@@ -1,7 +1,7 @@
 package App::GenPericmdCompleterScript;
 
 our $DATE = '2015-08-19'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -156,6 +156,14 @@ _
             schema => 'bool*',
             tags => ['category:pericmd-attribute'],
         },
+        read_config => {
+            schema => 'bool*',
+            tags => ['category:pericmd-attribute'],
+        },
+        read_env => {
+            schema => 'bool*',
+            tags => ['category:pericmd-attribute'],
+        },
         get_subcommand_from_arg => {
             schema => ['int*', in=>[0,1,2]],
             default => 1,
@@ -168,7 +176,8 @@ sub gen_perinci_cmdline_completer_script {
 
     my %args = @_;
 
-    my $output_file = $args{output_file};
+    # XXX schema
+    my $output_file = $args{output_file} // '-';
 
     my $subcommands;
     my $sc_metas = {};
@@ -451,7 +460,7 @@ App::GenPericmdCompleterScript - Generate Perinci::CmdLine completer script
 
 =head1 VERSION
 
-This document describes version 0.02 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2015-08-19.
+This document describes version 0.03 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2015-08-19.
 
 =head1 FUNCTIONS
 
@@ -502,6 +511,10 @@ Arguments ('*' denotes required arguments):
 
 {en_US Program name that is being completed}.
 
+=item * B<read_config> => I<bool>
+
+=item * B<read_env> => I<bool>
+
 =item * B<skip_format> => I<bool>
 
 =item * B<subcommand> => I<array[str]>
